@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -161,49 +161,49 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     @staticmethod
     def connection_profile_path(
-        project: str, location: str, connectionProfile: str,
+        project: str, location: str, connection_profile: str,
     ) -> str:
         """Returns a fully-qualified connection_profile string."""
-        return "projects/{project}/locations/{location}/connectionProfiles/{connectionProfile}".format(
-            project=project, location=location, connectionProfile=connectionProfile,
+        return "projects/{project}/locations/{location}/connectionProfiles/{connection_profile}".format(
+            project=project, location=location, connection_profile=connection_profile,
         )
 
     @staticmethod
     def parse_connection_profile_path(path: str) -> Dict[str, str]:
         """Parses a connection_profile path into its component segments."""
         m = re.match(
-            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/connectionProfiles/(?P<connectionProfile>.+?)$",
+            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/connectionProfiles/(?P<connection_profile>.+?)$",
             path,
         )
         return m.groupdict() if m else {}
 
     @staticmethod
     def private_connection_path(
-        project: str, location: str, privateConnection: str,
+        project: str, location: str, private_connection: str,
     ) -> str:
         """Returns a fully-qualified private_connection string."""
-        return "projects/{project}/locations/{location}/privateConnections/{privateConnection}".format(
-            project=project, location=location, privateConnection=privateConnection,
+        return "projects/{project}/locations/{location}/privateConnections/{private_connection}".format(
+            project=project, location=location, private_connection=private_connection,
         )
 
     @staticmethod
     def parse_private_connection_path(path: str) -> Dict[str, str]:
         """Parses a private_connection path into its component segments."""
         m = re.match(
-            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/privateConnections/(?P<privateConnection>.+?)$",
+            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/privateConnections/(?P<private_connection>.+?)$",
             path,
         )
         return m.groupdict() if m else {}
 
     @staticmethod
     def route_path(
-        project: str, location: str, privateConnection: str, route: str,
+        project: str, location: str, private_connection: str, route: str,
     ) -> str:
         """Returns a fully-qualified route string."""
-        return "projects/{project}/locations/{location}/privateConnections/{privateConnection}/routes/{route}".format(
+        return "projects/{project}/locations/{location}/privateConnections/{private_connection}/routes/{route}".format(
             project=project,
             location=location,
-            privateConnection=privateConnection,
+            private_connection=private_connection,
             route=route,
         )
 
@@ -211,7 +211,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
     def parse_route_path(path: str) -> Dict[str, str]:
         """Parses a route path into its component segments."""
         m = re.match(
-            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/privateConnections/(?P<privateConnection>.+?)/routes/(?P<route>.+?)$",
+            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/privateConnections/(?P<private_connection>.+?)/routes/(?P<route>.+?)$",
             path,
         )
         return m.groupdict() if m else {}
@@ -405,15 +405,12 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def list_connection_profiles(
         self,
-        request: datastream.ListConnectionProfilesRequest = None,
+        request: Union[datastream.ListConnectionProfilesRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -424,7 +421,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         in a project and location.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.ListConnectionProfilesRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.ListConnectionProfilesRequest, dict]):
                 The request object.
             parent (str):
                 Required. The parent that owns the
@@ -491,7 +488,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def get_connection_profile(
         self,
-        request: datastream.GetConnectionProfileRequest = None,
+        request: Union[datastream.GetConnectionProfileRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -502,7 +499,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         profile.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.GetConnectionProfileRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.GetConnectionProfileRequest, dict]):
                 The request object.
             name (str):
                 Required. The name of the connection
@@ -560,7 +557,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def create_connection_profile(
         self,
-        request: datastream.CreateConnectionProfileRequest = None,
+        request: Union[datastream.CreateConnectionProfileRequest, dict] = None,
         *,
         parent: str = None,
         connection_profile: datastream_resources.ConnectionProfile = None,
@@ -573,7 +570,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         project and location.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.CreateConnectionProfileRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.CreateConnectionProfileRequest, dict]):
                 The request object.
             parent (str):
                 Required. The parent that owns the
@@ -663,7 +660,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def update_connection_profile(
         self,
-        request: datastream.UpdateConnectionProfileRequest = None,
+        request: Union[datastream.UpdateConnectionProfileRequest, dict] = None,
         *,
         connection_profile: datastream_resources.ConnectionProfile = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -675,7 +672,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         connection profile.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.UpdateConnectionProfileRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.UpdateConnectionProfileRequest, dict]):
                 The request object.
             connection_profile (google.cloud.datastream_v1alpha1.types.ConnectionProfile):
                 Required. The ConnectionProfile to
@@ -763,7 +760,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def delete_connection_profile(
         self,
-        request: datastream.DeleteConnectionProfileRequest = None,
+        request: Union[datastream.DeleteConnectionProfileRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -773,7 +770,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         r"""Use this method to delete a connection profile..
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.DeleteConnectionProfileRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.DeleteConnectionProfileRequest, dict]):
                 The request object.
             name (str):
                 Required. The name of the connection
@@ -856,7 +853,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def discover_connection_profile(
         self,
-        request: datastream.DiscoverConnectionProfileRequest = None,
+        request: Union[datastream.DiscoverConnectionProfileRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -869,7 +866,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         that's optionally supplied in the request.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.DiscoverConnectionProfileRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.DiscoverConnectionProfileRequest, dict]):
                 The request object. Request message for 'discover'
                 ConnectionProfile request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -910,7 +907,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def list_streams(
         self,
-        request: datastream.ListStreamsRequest = None,
+        request: Union[datastream.ListStreamsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -921,7 +918,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         location.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.ListStreamsRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.ListStreamsRequest, dict]):
                 The request object.
             parent (str):
                 Required. The parent that owns the
@@ -988,7 +985,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def get_stream(
         self,
-        request: datastream.GetStreamRequest = None,
+        request: Union[datastream.GetStreamRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -998,7 +995,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         r"""Use this method to get details about a stream.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.GetStreamRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.GetStreamRequest, dict]):
                 The request object.
             name (str):
                 Required. The name of the stream
@@ -1056,7 +1053,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def create_stream(
         self,
-        request: datastream.CreateStreamRequest = None,
+        request: Union[datastream.CreateStreamRequest, dict] = None,
         *,
         parent: str = None,
         stream: datastream_resources.Stream = None,
@@ -1068,7 +1065,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         r"""Use this method to create a stream.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.CreateStreamRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.CreateStreamRequest, dict]):
                 The request object.
             parent (str):
                 Required. The parent that owns the
@@ -1154,7 +1151,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def update_stream(
         self,
-        request: datastream.UpdateStreamRequest = None,
+        request: Union[datastream.UpdateStreamRequest, dict] = None,
         *,
         stream: datastream_resources.Stream = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -1166,7 +1163,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         stream.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.UpdateStreamRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.UpdateStreamRequest, dict]):
                 The request object.
             stream (google.cloud.datastream_v1alpha1.types.Stream):
                 Required. The stream resource to
@@ -1251,7 +1248,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def delete_stream(
         self,
-        request: datastream.DeleteStreamRequest = None,
+        request: Union[datastream.DeleteStreamRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1261,7 +1258,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         r"""Use this method to delete a stream.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.DeleteStreamRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.DeleteStreamRequest, dict]):
                 The request object.
             name (str):
                 Required. The name of the stream
@@ -1342,7 +1339,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def fetch_errors(
         self,
-        request: datastream.FetchErrorsRequest = None,
+        request: Union[datastream.FetchErrorsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -1352,7 +1349,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         stream.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.FetchErrorsRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.FetchErrorsRequest, dict]):
                 The request object. Request message for 'FetchErrors'
                 request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1404,7 +1401,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def fetch_static_ips(
         self,
-        request: datastream.FetchStaticIpsRequest = None,
+        request: Union[datastream.FetchStaticIpsRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1417,7 +1414,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         optionally supplied in the request.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.FetchStaticIpsRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.FetchStaticIpsRequest, dict]):
                 The request object. Request message for 'FetchStaticIps'
                 request.
             name (str):
@@ -1487,7 +1484,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def create_private_connection(
         self,
-        request: datastream.CreatePrivateConnectionRequest = None,
+        request: Union[datastream.CreatePrivateConnectionRequest, dict] = None,
         *,
         parent: str = None,
         private_connection: datastream_resources.PrivateConnection = None,
@@ -1500,7 +1497,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         configuration.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.CreatePrivateConnectionRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.CreatePrivateConnectionRequest, dict]):
                 The request object.
             parent (str):
                 Required. The parent that owns the
@@ -1590,7 +1587,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def get_private_connection(
         self,
-        request: datastream.GetPrivateConnectionRequest = None,
+        request: Union[datastream.GetPrivateConnectionRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1601,7 +1598,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         connectivity configuration.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.GetPrivateConnectionRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.GetPrivateConnectionRequest, dict]):
                 The request object.
             name (str):
                 Required. The name of the  private
@@ -1663,7 +1660,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def list_private_connections(
         self,
-        request: datastream.ListPrivateConnectionsRequest = None,
+        request: Union[datastream.ListPrivateConnectionsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1674,7 +1671,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         configurations in a project and location.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.ListPrivateConnectionsRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.ListPrivateConnectionsRequest, dict]):
                 The request object.
             parent (str):
                 Required. The parent that owns the
@@ -1742,7 +1739,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def delete_private_connection(
         self,
-        request: datastream.DeletePrivateConnectionRequest = None,
+        request: Union[datastream.DeletePrivateConnectionRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1753,7 +1750,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         configuration.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.DeletePrivateConnectionRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.DeletePrivateConnectionRequest, dict]):
                 The request object.
             name (str):
                 Required. The name of the private
@@ -1836,7 +1833,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def create_route(
         self,
-        request: datastream.CreateRouteRequest = None,
+        request: Union[datastream.CreateRouteRequest, dict] = None,
         *,
         parent: str = None,
         route: datastream_resources.Route = None,
@@ -1849,7 +1846,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         connectivity in a project and location.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.CreateRouteRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.CreateRouteRequest, dict]):
                 The request object. route creation request
             parent (str):
                 Required. The parent that owns the
@@ -1936,7 +1933,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def get_route(
         self,
-        request: datastream.GetRouteRequest = None,
+        request: Union[datastream.GetRouteRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1946,7 +1943,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         r"""Use this method to get details about a route.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.GetRouteRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.GetRouteRequest, dict]):
                 The request object. route get request
             name (str):
                 Required. The name of the Route
@@ -2008,7 +2005,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def list_routes(
         self,
-        request: datastream.ListRoutesRequest = None,
+        request: Union[datastream.ListRoutesRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -2019,7 +2016,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         connectivity in a project and location.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.ListRoutesRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.ListRoutesRequest, dict]):
                 The request object. route list request
             parent (str):
                 Required. The parent that owns the
@@ -2087,7 +2084,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
 
     def delete_route(
         self,
-        request: datastream.DeleteRouteRequest = None,
+        request: Union[datastream.DeleteRouteRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -2097,7 +2094,7 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         r"""Use this method to delete a route.
 
         Args:
-            request (google.cloud.datastream_v1alpha1.types.DeleteRouteRequest):
+            request (Union[google.cloud.datastream_v1alpha1.types.DeleteRouteRequest, dict]):
                 The request object. route deletion request
             name (str):
                 Required. The name of the Route
@@ -2176,6 +2173,19 @@ class DatastreamClient(metaclass=DatastreamClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
